module Config.Helpers.Headers.Records exposing
    ( argumentHeader
    , blogHeader
    , contactHeader
    , cuckListHeader
    , debateHeader
    , donateHeader
    , gibberishHeader
    , interviewHeader
    , nutriDexHeader
    , servicesHeader
    )

import Config.Helpers.Cards.Inner.Text exposing (detailBodyLink)
import Config.Helpers.Headers.Types exposing (Header)
import Config.Style.Colour.Helpers exposing (ThemeColor(..))
import Element as E
    exposing
        ( newTabLink
        , text
        )
import Route.Path as Path


argumentHeader : Header msg
argumentHeader =
    let
        name =
            "Arguments"
    in
    { headerTitle = String.toUpper name
    , headerBody = [ text "This page features arguments that I hold to be sound. I'm open to hearing all challenges, as I am ready to engage with and defend any argument listed." ]
    }


blogHeader : Header msg
blogHeader =
    let
        name =
            "Blog"
    in
    { headerTitle = String.toUpper name
    , headerBody = [ text "This page features blog articles written by me, along with contributions from guest authors, covering topics primarily related to nutrition science, health science, and article." ]
    }


cuckListHeader : Header msg
cuckListHeader =
    let
        name =
            "Cucklist"
    in
    { headerTitle = String.toUpper name
    , headerBody = [ text "This page features a list of morons who wrote cheques with their mouths that their asses couldn't cash. Each person included in this list has dodged debating me." ]
    }


debateHeader : Header msg
debateHeader =
    let
        name =
            "Debate"
    in
    { headerTitle = String.toUpper name
    , headerBody = [ text "Here you will find links to various pages relevant to debate, such as formal arguments, a list of debate-dodging cucks, and an inventory of nonsensical terminology." ]
    }


donateHeader : Header msg
donateHeader =
    let
        name =
            "Donate"
    in
    { headerTitle = String.toUpper name
    , headerBody = [ text "My site, research, and content all cost time and money to run. If you find my contributions valuable, please consider supporting my work on any of the platforms listed below!" ]
    }


gibberishHeader : Header msg
gibberishHeader =
    let
        name =
            "Gibberish"
    in
    { headerTitle = String.toUpper name
    , headerBody = [ text "This page is specifically for terms and ostensible concepts that I think are either nonsensical or so practically useless that its intelligiblity is irrelevant." ]
    }


servicesHeader : Header msg
servicesHeader =
    let
        name =
            "Services"
    in
    { headerTitle = String.toUpper name
    , headerBody =
        [ text "Here are all the services I offer to interested clients. Feel free to "
        , newTabLink []
            { url = Path.toString Path.Contact_Inquiry
            , label = detailBodyLink TextLightOrange "reach out"
            }
        , text " with any questions or to receive a quote for bundled purchases."
        ]
    }


interviewHeader : Header msg
interviewHeader =
    let
        name =
            "Interviews"
    in
    { headerTitle = String.toUpper name
    , headerBody = [ text "This page showcases various podcasts and shows I've been on. If you’d like to have me as a guest on your podcast, feel free to reach out!" ]
    }


nutriDexHeader : Header msg
nutriDexHeader =
    let
        name =
            "The NutriDex"
    in
    { headerTitle = String.toUpper name
    , headerBody = [ text "" ]
    }


contactHeader : Header msg
contactHeader =
    let
        name =
            "Contact"
    in
    { headerTitle = String.toUpper name
    , headerBody = [ text "If you wish to contact me, please carefully choose from the following options before reaching out, to make sure that your communication ends up in the right place." ]
    }
