module Config.Pages.Blog.Records.PlantBasedMeta exposing (articlePlantBasedMeta)

import Config.Pages.Blog.Types exposing (BlogArticle)
import Route.Path as Path


articlePlantBasedMeta : BlogArticle
articlePlantBasedMeta =
    { articleName = "Plant-Based Diets (An Independent Meta-Analysis)"
    , articleLink = Path.toString Path.Blog_Plantbasedmeta
    , articleAuthor = "Nick Hiebert"
    , isNewTabLink = False
    , hasReferences = True
    , hasTableOfContents = True
    , articleImage = "plantbasedmeta"
    , articlePublished = "Feb 5, 2021"
    , articleBody = """
On the back of my independent meta-analysis investigating the relationship between low carbohydrate/ketogenic diets and health markers in intervention trials, I now give you my independent meta-analysis investigating the relationship between plant-based diets and health markers in intervention trials. 

The plant-based community has just as much of a tendency to cherry-pick study results as any other diet community wherein certainty is low and guruism is high. This independent meta-analysis is my attempt to add some clarity to online and academic discourse regarding plant-based diets and health—do these types of diets actually live up to the hype?

It is my hope that this blog article might serve as an educational resource for anyone aiming to learn about how plant-based diets could relate to health. As well as whether or not those health outcomes are independent of duration or weight loss. There are many supposed effects of plant-based that many of us may just take for granted, such as reductions in low density lipoprotein cholesterol or lower inflammatory markers. However, it is unclear whether or not these effects, if they exist at all, are independent of weight loss or the duration of time spent on the diet.

It is also true that some of us may expect negative things to happen on a plant-based diet, like elevated triglycerides or higher blood glucose. It is likewise unclear whether or not these effects are independent of weight loss or the total amount of time spent on the diet. Hopefully the data below will help inform some of these debates and discussions, as well as help rectify any potential misconceptions one might have.

I will also not be including any interpretations of any of the data. I am not a health professional of any kind, and it is not my job to interpret this data. I searched for it. I collated it. And now it's yours. 

Results will be stratified six ways: 

1. Plant-based diets compared to control.

2. Plant-based diets compared to baseline.

3. Plant-based diets stratified by duration, compared to control.

4. Plant-based diets stratified by duration, compared to baseline.

5. Plant-based diets stratified by weight loss, compared to control.

6. Plant-based diets stratified by weight loss, compared to baseline.

**Inclusion Criteria:**

Due to the fact that there is no clear, standardized definition of a "plant-based" diet in the literature, the inclusion criteria for this meta-analysis was difficult to formulate. An obvious correlate for a diet that emphasizes plant foods might be dietary cholesterol (due to it only being found in animal foods). However, no trial actually achieved a zero-cholesterol diet in the intervention group, and some diets may be higher in dietary cholesterol despite a significant overall decrease in animal food consumption. For example, a diet that substitutes 150 kcal of eggs for 1000 kcal of assorted animal products could potentially have the exact same dietary cholesterol yield overall, despite the fact that one diet may be significantly more plant-based than the other diet.

A minority of studies divulged the percentage of calories from either animal foods or non-animal foods in the intervention diets. So, such criteria would have narrowed the range of eligible trials to an unacceptable degree. In order to insulate myself from criticisms to the greatest degree possible, I let the literature itself dictate my inclusion criteria. If the experimental diet used in an intervention trial had been referenced as "plant-based" or "vegan" in the literature (either in a meta-analysis, narrative review, systematic review, trial paper, etc.), I invoked the if-it-is-good-enough-for-them-it-is-good-enough-for-me principle, and included them. Don't fucking @ me, bro.

**Disclaimer:**

This is not a peer-reviewed publication. This blog article is for educational and/or entertainment purposes only. This blog article is not an academic reference, nor does it stand in place of current or future peer reviewed, academic research into plant-based diets and health. There are multiple methodological limitations that make robust interpretation challenging in many cases.

If you have enjoyed my work and want me to continue producing this sort of content, consider supporting me on Patreon. Every little bit helps! Thank you for your time! Enjoy!

# ANTHROPOMETRICS

# BODY WEIGHT

**Body Weight: Plant-based (vs Control)**

![][image5]
[image5]: /blog/plantbasedmeta/image5.png 

**Body Weight: Plant-based (vs Baseline)**

![][image6]
[image6]: /blog/plantbasedmeta/image6.png 

**Body Weight: Plant-based by Duration (vs Control)**

![][image7]
[image7]: /blog/plantbasedmeta/image7.png 

**Body Weight: Plant-based by Duration (vs Baseline)**

![][image8]
[image8]: /blog/plantbasedmeta/image8.png 

**Body Weight: Plant-based by Weight Loss (vs Control)**

![][image9]
[image9]: /blog/plantbasedmeta/image9.png 

**Body Weight: Plant-based by Weight Loss (vs Baseline)**

![][image10]
[image10]: /blog/plantbasedmeta/image10.png 

# BODY FAT MASS

**Body Fat Mass: Plant-based (vs Control)**

![][image11]
[image11]: /blog/plantbasedmeta/image11.png 

**Body Fat Mass: Plant-based (vs Baseline)**

![][image12]
[image12]: /blog/plantbasedmeta/image12.png 

**Body Fat Mass: Plant-based by Duration (vs Control)**

![][image13]
[image13]: /blog/plantbasedmeta/image13.png 

**Body Fat Mass: Plant-based by Duration (vs Baseline)**

![][image14]
[image14]: /blog/plantbasedmeta/image14.png 

**Body Fat Mass: Plant-based by Weight Loss (vs Control)**

![][image15]
[image15]: /blog/plantbasedmeta/image15.png 

**Body Fat Mass: Plant-based by Weight Loss (vs Baseline)**

![][image16]
[image16]: /blog/plantbasedmeta/image16.png 

# FAT FREE MASS

**Fat Free Mass: Plant-based (vs Control)**

![][image17]
[image17]: /blog/plantbasedmeta/image17.png 

**Fat Free Mass: Plant-based (vs Baseline)**

![][image18]
[image18]: /blog/plantbasedmeta/image18.png 

**Fat Free Mass: Plant-based by Duration (vs Control)**

![][image19]
[image19]: /blog/plantbasedmeta/image19.png 

**Fat Free Mass: Plant-based by Duration (vs Baseline)**

![][image20]
[image20]: /blog/plantbasedmeta/image20.png 

**Fat Free Mass: Plant-based by Weight Loss (vs Control)**

![][image21]
[image21]: /blog/plantbasedmeta/image21.png 

**Fat Free Mass: Plant-based by Weight Loss (vs Baseline)**

![][image22]
[image22]: /blog/plantbasedmeta/image22.png 

# BODY MASS INDEX

**Body Mass Index: Plant-based (vs Control)**

![][image23]
[image23]: /blog/plantbasedmeta/image23.png 

**Body Mass Index: Plant-based (vs Baseline)**

![][image24]
[image24]: /blog/plantbasedmeta/image24.png 

**Body Mass Index: Plant-based by Duration (vs Control)**

![][image25]
[image25]: /blog/plantbasedmeta/image25.png 

**Body Mass Index: Plant-based by Duration (vs Baseline)**

![][image26]
[image26]: /blog/plantbasedmeta/image26.png 

**Body Mass Index: Plant-based by Weight Loss (vs Control)**

![][image27]
[image27]: /blog/plantbasedmeta/image27.png 

**Body Mass Index: Plant-based by Weight Loss (vs Baseline)**

![][image28]
[image28]: /blog/plantbasedmeta/image28.png 

# WAIST HIP RATIO

**Waist Hip Ratio: Plant-based (vs Control)**

![][image29]
[image29]: /blog/plantbasedmeta/image29.png 

**Waist Hip Ratio: Plant-based (vs Baseline)**

![][image30]
[image30]: /blog/plantbasedmeta/image30.png 

**Waist Hip Ratio: Plant-based by Duration (vs Control)**

![][image31]
[image31]: /blog/plantbasedmeta/image31.png 

**Waist Hip Ratio: Plant-based by Duration (vs Baseline)**

![][image32]
[image32]: /blog/plantbasedmeta/image32.png 

**Waist Hip Ratio: Plant-based by Weight Loss (vs Control)**

![][image33]
[image33]: /blog/plantbasedmeta/image33.png 

**Waist Hip Ratio: Plant-based by Weight Loss (vs Baseline)**

![][image34]
[image34]: /blog/plantbasedmeta/image34.png 

# VISCERAL ADIPOSE TISSUE

**Visceral Adipose Tissue: Plant-based (vs Control)**

![][image35]
[image35]: /blog/plantbasedmeta/image35.png 

**Visceral Adipose Tissue: Plant-based (vs Baseline)**

![][image36]
[image36]: /blog/plantbasedmeta/image36.png 

# INTRAHEPATIC LIPID

**Intrahepatic Lipid: Plant-based (vs Control)**

![][image37]
[image37]: /blog/plantbasedmeta/image37.png 

**Intrahepatic Lipid: Plant-based (vs Baseline)**

![][image38]
[image38]: /blog/plantbasedmeta/image38.png 

**Intrahepatic Lipid: Plant-based by Duration (vs Control)**

![][image39]
[image39]: /blog/plantbasedmeta/image39.png 

**Intrahepatic Lipid: Plant-based by Duration (vs Baseline)**

![][image40]
[image40]: /blog/plantbasedmeta/image40.png 

**Intrahepatic Lipid: Plant-based by Weight Loss (vs Control)**

![][image41]
[image41]: /blog/plantbasedmeta/image41.png 

**Intrahepatic Lipid: Plant-based by Weight Loss (vs Baseline)**

![][image42]
[image42]: /blog/plantbasedmeta/image42.png 

# INTRAMYOCELLULAR LIPID

**Intramyocellular Lipid: Plant-based (vs Control)**

![][image43]
[image43]: /blog/plantbasedmeta/image43.png 

**Intramyocellular Lipid: Plant-based (vs Baseline)**

![][image44]
[image44]: /blog/plantbasedmeta/image44.png 

# CARDIOVASCULAR

# SYSTOLIC BLOOD PRESSURE

**Systolic Blood Pressure: Plant-based (vs Control)**

![][image45]
[image45]: /blog/plantbasedmeta/image45.png 

**Systolic Blood Pressure: Plant-based (vs Baseline)**

![][image46]
[image46]: /blog/plantbasedmeta/image46.png 

**Systolic Blood Pressure: Plant-based by Duration (vs Control)**

![][image47]
[image47]: /blog/plantbasedmeta/image47.png 

**Systolic Blood Pressure: Plant-based by Duration (vs Baseline)**

![][image48]
[image48]: /blog/plantbasedmeta/image48.png 

**Systolic Blood Pressure: Plant-based by Weight Loss (vs Control)**

![][image49]
[image49]: /blog/plantbasedmeta/image49.png 

**Systolic Blood Pressure: Plant-based by Weight Loss (vs Baseline)**

![][image50]
[image50]: /blog/plantbasedmeta/image50.png 

# DIASTOLIC BLOOD PRESSURE

**Diastolic Blood Pressure: Plant-based (vs Control)**

![][image51]
[image51]: /blog/plantbasedmeta/image51.png 

**Diastolic Blood Pressure: Plant-based (vs Baseline)**

![][image52]
[image52]: /blog/plantbasedmeta/image52.png 

**Diastolic Blood Pressure: Plant-based by Duration (vs Control)**

![][image53]
[image53]: /blog/plantbasedmeta/image53.png 

**Diastolic Blood Pressure: Plant-based by Duration (vs Baseline)**

![][image54]
[image54]: /blog/plantbasedmeta/image54.png 

**Diastolic Blood Pressure: Plant-based by Weight Loss (vs Control)**

![][image55]
[image55]: /blog/plantbasedmeta/image55.png 

**Diastolic Blood Pressure: Plant-based by Weight Loss (vs Baseline)**

![][image56]
[image56]: /blog/plantbasedmeta/image56.png 

# CHEMISTRY

# HEMAGLOBIN A1C

**Hemoglobin A1C: Plant-based (vs Control)**

![][image57]
[image57]: /blog/plantbasedmeta/image57.png 

**Hemoglobin A1C: Plant-based (vs Baseline)**

![][image58]
[image58]: /blog/plantbasedmeta/image58.png 

**Hemoglobin A1C: Plant-based by Duration (vs Control)**

![][image59]
[image59]: /blog/plantbasedmeta/image59.png 

**Hemoglobin A1C: Plant-based by Duration (vs Baseline)**

![][image60]
[image60]: /blog/plantbasedmeta/image60.png 

**Hemoglobin A1C: Plant-based by Weight Loss (vs Control)**

![][image61]
[image61]: /blog/plantbasedmeta/image61.png 

**Hemoglobin A1C: Plant-based by Weight Loss (vs Baseline)**

![][image62]
[image62]: /blog/plantbasedmeta/image62.png 

# BLOOD GLUCOSE

**Blood Glucose: Plant-based (vs Control)**

![][image63]
[image63]: /blog/plantbasedmeta/image63.png 

**Blood Glucose: Plant-based (vs Baseline)**

![][image64]
[image64]: /blog/plantbasedmeta/image64.png 

**Blood Glucose: Plant-based by Duration (vs Control)**

![][image65]
[image65]: /blog/plantbasedmeta/image65.png 

**Blood Glucose: Plant-based by Duration (vs Baseline)**

![][image66]
[image66]: /blog/plantbasedmeta/image66.png 

**Blood Glucose: Plant-based by Weight Loss (vs Control)**

![][image67]
[image67]: /blog/plantbasedmeta/image67.png 

**Blood Glucose: Plant-based by Weight Loss (vs Baseline)**

![][image68]
[image68]: /blog/plantbasedmeta/image68.png 

# URIC ACID

**Uric Acid: Plant-based (vs Control)**

![][image69]
[image69]: /blog/plantbasedmeta/image69.png 

**Uric Acid: Plant-based (vs Baseline)**

![][image70]
[image70]: /blog/plantbasedmeta/image70.png 

**Uric Acid: Plant-based by Duration (vs Control)**

![][image71]
[image71]: /blog/plantbasedmeta/image71.png 

**Uric Acid: Plant-based by Duration (vs Baseline)**

![][image72]
[image72]: /blog/plantbasedmeta/image72.png 

# WHITE BLOOD CELL COUNT

**White Blood Cell Count: Plant-based (vs Control)**

![][image73]
[image73]: /blog/plantbasedmeta/image73.png 

**White Blood Cell Count: Plant-based (vs Baseline)**

![][image74]
[image74]: /blog/plantbasedmeta/image74.png 

**White Blood Cell Count: Plant-based by Duration (vs Control)**

![][image75]
[image75]: /blog/plantbasedmeta/image75.png 

**White Blood Cell Count: Plant-based by Duration (vs Baseline)**

![][image76]
[image76]: /blog/plantbasedmeta/image76.png 

#TRIMETHYLAMINE N-OXIDE

**Trimethylamine N-Oxide: Plant-based (vs Control)**

![][image77]
[image77]: /blog/plantbasedmeta/image77.png 

**Trimethylamine N-Oxide: Plant-based (vs Baseline)**

![][image78]
[image78]: /blog/plantbasedmeta/image78.png 

# MALONDIALDEHYDE

**Malondialdehyde: Plant-based (vs Control)**

![][image79]
[image79]: /blog/plantbasedmeta/image79.png 

**Malondialdehyde: Plant-based (vs Baseline)**

![][image80]
[image80]: /blog/plantbasedmeta/image80.png 

**Malondialdehyde: Plant-based by Duration (vs Control)**

![][image81]
[image81]: /blog/plantbasedmeta/image81.png 

**Malondialdehyde: Plant-based by Duration (vs Baseline)**

![][image82]
[image82]: /blog/plantbasedmeta/image82.png 

# ENDOCRINE

# INSULIN

**Insulin: Plant-based (vs Control)**

![][image83]
[image83]: /blog/plantbasedmeta/image83.png 

**Insulin: Plant-based (vs Baseline)**

![][image84]
[image84]: /blog/plantbasedmeta/image84.png 

**Insulin: Plant-based by Duration (vs Control)**

![][image85]
[image85]: /blog/plantbasedmeta/image85.png 

**Insulin: Plant-based by Duration (vs Baseline)**

![][image86]
[image86]: /blog/plantbasedmeta/image86.png 

**Insulin: Plant-based by Weight Loss (vs Control)**

![][image87]
[image87]: /blog/plantbasedmeta/image87.png 

**Insulin: Plant-based by Weight Loss (vs Baseline)**

![][image88]
[image88]: /blog/plantbasedmeta/image88.png 

# INSULIN-LIKE GROWTH FACTOR 1

**Insulin-Like Growth Factor 1: Plant-based (vs Control)**

![][image89]
[image89]: /blog/plantbasedmeta/image89.png 

**Insulin-Like Growth Factor 1: Plant-based (vs Baseline)**

![][image90]
[image90]: /blog/plantbasedmeta/image90.png 

# INFLAMMATION

# HIGH SENSITIVITY C-REACTIVE PROTEIN

**High Sensitivity C-Reactive Protein: Plant-based (vs Control)**

![][image91]
[image91]: /blog/plantbasedmeta/image91.png 

**High Sensitivity C-Reactive Protein: Plant-based (vs Baseline)**

![][image92]
[image92]: /blog/plantbasedmeta/image92.png 

**High Sensitivity C-Reactive Protein: Plant-based by Duration (vs Control)**

![][image93]
[image93]: /blog/plantbasedmeta/image93.png 

**High Sensitivity C-Reactive Protein: Plant-based by Duration (vs Baseline)**

![][image94]
[image94]: /blog/plantbasedmeta/image94.png 

**High Sensitivity C-Reactive Protein: Plant-based by Weight Loss (vs Control)**

![][image95]
[image95]: /blog/plantbasedmeta/image95.png 

**High Sensitivity C-Reactive Protein: Plant-based by Weight Loss (vs Baseline)**

![][image96]
[image96]: /blog/plantbasedmeta/image96.png 

# LOW SENSITIVITY C-REACTIVE PROTEIN

**Low Sensitivity C-Reactive Protein: Plant-based (vs Control)**

![][image97]
[image97]: /blog/plantbasedmeta/image97.png 

**Low Sensitivity C-Reactive Protein: Plant-based (vs Baseline)**

![][image98]
[image98]: /blog/plantbasedmeta/image98.png 

**Low Sensitivity C-Reactive Protein: Plant-based by Duration (vs Control)**

![][image99]
[image99]: /blog/plantbasedmeta/image99.png 

**Low Sensitivity C-Reactive Protein: Plant-based by Duration (vs Baseline)**

![][image100]
[image100]: /blog/plantbasedmeta/image100.png 

# TUMOR NECROSIS FACTOR

**Tumor Necrosis Factor: Plant-based (vs Control)**

![][image101]
[image101]: /blog/plantbasedmeta/image101.png 

**Tumor Necrosis Factor: Plant-based (vs Baseline)**

![][image102]
[image102]: /blog/plantbasedmeta/image102.png 

# INTERCELLULAR ADHESION MOLECULE 1

**Intercellular Adhesion Molecule 1: Plant-based (vs Control)**

![][image103]
[image103]: /blog/plantbasedmeta/image103.png 

**Intercellular Adhesion Molecule 1: Plant-based (vs Baseline)**

![][image104]
[image104]: /blog/plantbasedmeta/image104.png 

**Intercellular Adhesion Molecule 1: Plant-based by Duration (vs Control)**

![][image105]
[image105]: /blog/plantbasedmeta/image105.png 

**Intercellular Adhesion Molecule 1: Plant-based by Duration (vs Baseline)**

![][image106]
[image106]: /blog/plantbasedmeta/image106.png 

# VASCULAR CELLULAR ADHESION MOLECULE 1

**Vascular Cellular Adhesion Molecule 1: Plant-based (vs Control)**

![][image107]
[image107]: /blog/plantbasedmeta/image107.png 

**Vascular Cellular Adhesion Molecule 1: Plant-based (vs Baseline)**

![][image108]
[image108]: /blog/plantbasedmeta/image108.png 

**Vascular Cellular Adhesion Molecule 1: Plant-based by Duration (vs Control)**

![][image109]
[image109]: /blog/plantbasedmeta/image109.png 

**Vascular Cellular Adhesion Molecule 1: Plant-based by Duration (vs Baseline)**

![][image110]
[image110]: /blog/plantbasedmeta/image110.png 

# MONOCYTE CHEMOATTRACTANT PROTEIN-1

**Monocyte Chemoattractant Protein-1: Plant-based (vs Control)**

![][image111]
[image111]: /blog/plantbasedmeta/image111.png 

**Monocyte Chemoattractant Protein-1: Plant-based (vs Baseline)**

![][image112]
[image112]: /blog/plantbasedmeta/image112.png 

# INTERLEUKIN 6

**Interleukin 6: Plant-based (vs Control)**

![][image113]
[image113]: /blog/plantbasedmeta/image113.png 

**Interleukin 6: Plant-based (vs Baseline)**

![][image114]
[image114]: /blog/plantbasedmeta/image114.png 

**Interleukin 6: Plant-based by Duration (vs Control)**

![][image115]
[image115]: /blog/plantbasedmeta/image115.png 

**Interleukin 6: Plant-based by Duration (vs Baseline)**

![][image116]
[image116]: /blog/plantbasedmeta/image116.png 

# INTERLEUKIN 8

**Interleukin 8: Plant-based (vs Control)**

![][image117]
[image117]: /blog/plantbasedmeta/image117.png 

**Interleukin 8: Plant-based (vs Baseline)**

![][image118]
[image118]: /blog/plantbasedmeta/image118.png 

# INTERLEUKIN 10

**Interleukin 10: Plant-based (vs Control)**

![][image119]
[image119]: /blog/plantbasedmeta/image119.png 

**Interleukin 10: Plant-based (vs Baseline)**

![][image120]
[image120]: /blog/plantbasedmeta/image120.png 

# KIDNEY FUNCTION

# UREA

**Urea: Plant-based (vs Control)**

![][image121]
[image121]: /blog/plantbasedmeta/image121.png 

**Urea: Plant-based (vs Baseline)**

![][image122]
[image122]: /blog/plantbasedmeta/image122.png 

# LIPIDOLOGY

# LOW DENSITY LIPOPROTEIN CHOLESTEROL

**Low Density Lipoprotein Cholesterol: Plant-based (vs Control)**

![][image123]
[image123]: /blog/plantbasedmeta/image123.png 

**Low Density Lipoprotein Cholesterol: Plant-based (vs Baseline)**

![][image124]
[image124]: /blog/plantbasedmeta/image124.png 

**Low Density Lipoprotein Cholesterol: Plant-based by Duration (vs Control)**

![][image125]
[image125]: /blog/plantbasedmeta/image125.png 

**Low Density Lipoprotein Cholesterol: Plant-based by Duration (vs Baseline)**

![][image126]
[image126]: /blog/plantbasedmeta/image126.png 

**Low Density Lipoprotein Cholesterol: Plant-based by Weight Loss (vs Control)**

![][image127]
[image127]: /blog/plantbasedmeta/image127.png 

**Low Density Lipoprotein Cholesterol: Plant-based by Weight Loss (vs Baseline)**

![][image128]
[image128]: /blog/plantbasedmeta/image128.png 

# HIGH DENSITY LIPOPROTEIN CHOLESTEROL

**High Density Lipoprotein Cholesterol: Plant-based (vs Control)**

![][image129]
[image129]: /blog/plantbasedmeta/image129.png 

**High Density Lipoprotein Cholesterol: Plant-based (vs Baseline)**

![][image130]
[image130]: /blog/plantbasedmeta/image130.png 

**High Density Lipoprotein Cholesterol: Plant-based by Duration (vs Control)**

![][image131]
[image131]: /blog/plantbasedmeta/image131.png 

**High Density Lipoprotein Cholesterol: Plant-based by Duration (vs Baseline)**

![][image132]
[image132]: /blog/plantbasedmeta/image132.png 

**High Density Lipoprotein Cholesterol: Plant-based by Weight Loss (vs Control)**

![][image133]
[image133]: /blog/plantbasedmeta/image133.png 

**High Density Lipoprotein Cholesterol: Plant-based by Weight Loss (vs Baseline)**

![][image134]
[image134]: /blog/plantbasedmeta/image134.png 

# TRIGLYCERIDES

**Triglycerides: Plant-based (vs Control)**

![][image135]
[image135]: /blog/plantbasedmeta/image135.png 

**Triglycerides: Plant-based (vs Baseline)**

![][image136]
[image136]: /blog/plantbasedmeta/image136.png 

**Triglycerides: Plant-based by Duration (vs Control)**

![][image137]
[image137]: /blog/plantbasedmeta/image137.png 

**Triglycerides: Plant-based by Duration (vs Baseline)**

![][image138]
[image138]: /blog/plantbasedmeta/image138.png 

**Triglycerides: Plant-based by Weight Loss (vs Control)**

![][image139]
[image139]: /blog/plantbasedmeta/image139.png 

**Triglycerides: Plant-based by Weight Loss (vs Baseline)**

![][image140]
[image140]: /blog/plantbasedmeta/image140.png 

# APOLIPOPROTEIN B

**Apolipoprotein B: Plant-based (vs Control)**

![][image141]
[image141]: /blog/plantbasedmeta/image141.png 

**Apolipoprotein B: Plant-based (vs Baseline)**

![][image142]
[image142]: /blog/plantbasedmeta/image142.png 

**Apolipoprotein B: Plant-based by Duration (vs Control)**

![][image143]
[image143]: /blog/plantbasedmeta/image143.png 

**Apolipoprotein B: Plant-based by Duration (vs Baseline)**

![][image144]
[image144]: /blog/plantbasedmeta/image144.png 

**Apolipoprotein B: Plant-based by Weight Loss (vs Control)**

![][image145]
[image145]: /blog/plantbasedmeta/image145.png 

**Apolipoprotein B: Plant-based by Weight Loss (vs Baseline)**

![][image146]
[image146]: /blog/plantbasedmeta/image146.png 

# APOLIPOPROTEIN A1

**Apolipoprotein A1: Plant-based (vs Control)**

![][image147]
[image147]: /blog/plantbasedmeta/image147.png 

**Apolipoprotein A1: Plant-based (vs Baseline)**

![][image148]
[image148]: /blog/plantbasedmeta/image148.png 

**Apolipoprotein A1: Plant-based by Duration (vs Control)**

![][image149]
[image149]: /blog/plantbasedmeta/image149.png 

**Apolipoprotein A1: Plant-based by Duration (vs Baseline)**

![][image150]
[image150]: /blog/plantbasedmeta/image150.png 

**Apolipoprotein A1: Plant-based by Weight Loss (vs Control)**

![][image151]
[image151]: /blog/plantbasedmeta/image151.png 

**Apolipoprotein A1: Plant-based by Weight Loss (vs Baseline)**

![][image152]
[image152]: /blog/plantbasedmeta/image152.png 

# LOW DENSITY LIPOPROTEIN PARTICLE COUNT

**Low Density Lipoprotein Particle Count: Plant-based (vs Control)**

![][image153]
[image153]: /blog/plantbasedmeta/image153.png 

**Low Density Lipoprotein Particle Count: Plant-based (vs Baseline)**

![][image154]
[image154]: /blog/plantbasedmeta/image154.png 

**Low Density Lipoprotein Particle Count: Plant-based by Duration (vs Control)**

![][image155]
[image155]: /blog/plantbasedmeta/image155.png 

**Low Density Lipoprotein Particle Count: Plant-based by Duration (vs Baseline)**

![][image156]
[image156]: /blog/plantbasedmeta/image156.png 

# LOW DENSITY LIPOPROTEIN PARTICLE SIZE

**Low Density Lipoprotein Particle Size: Plant-based (vs Control)**

![][image157]
[image157]: /blog/plantbasedmeta/image157.png 

**Low Density Lipoprotein Particle Size: Plant-based (vs Baseline)**

![][image158]
[image158]: /blog/plantbasedmeta/image158.png 

**Low Density Lipoprotein Particle Size: Plant-based by Duration (vs Control)**

![][image159]
[image159]: /blog/plantbasedmeta/image159.png 

**Low Density Lipoprotein Particle Size: Plant-based by Duration (vs Baseline)**

![][image160]
[image160]: /blog/plantbasedmeta/image160.png 

# LIVER FUNCTION

**Alanine Aminotransferase (U/L)

![][image161]
[image161]: /blog/plantbasedmeta/image161.png 

**Alanine Aminotransferase: Plant-based (vs Control)**

![][image162]
[image162]: /blog/plantbasedmeta/image162.png 

**Alanine Aminotransferase: Plant-based (vs Baseline)**

![][image163]
[image163]: /blog/plantbasedmeta/image163.png 

**Alanine Aminotransferase: Plant-based by Duration (vs Control)**

![][image164]
[image164]: /blog/plantbasedmeta/image164.png 

**Alanine Aminotransferase: Plant-based by Duration (vs Baseline)**

![][image165]
[image165]: /blog/plantbasedmeta/image165.png 

# ASPARTATE AMINOTRANSFERASE

**Aspartate Aminotransferase: Plant-based (vs Control)**

![][image166]
[image166]: /blog/plantbasedmeta/image166.png 

**Aspartate Aminotransferase: Plant-based (vs Baseline)**

![][image167]
[image167]: /blog/plantbasedmeta/image167.png 

# GAMMA-GLUTAMYL TRANSFERASE

**Gamma-Glutamyl Transferase: Plant-based (vs Control)**

![][image168]
[image168]: /blog/plantbasedmeta/image168.png 

**Gamma-Glutamyl Transferase: Plant-based (vs Baseline)**

![][image169]
[image169]: /blog/plantbasedmeta/image169.png 

# BILIRUBIN

**Bilirubin: Plant-based (vs Control)**

![][image170]
[image170]: /blog/plantbasedmeta/image170.png 

**Bilirubin: Plant-based (vs Baseline)**

![][image171]
[image171]: /blog/plantbasedmeta/image171.png 

# THYROID FUNCTION

**Triiodothyronine (ng/dL)

![][image172]
[image172]: /blog/plantbasedmeta/image172.png 

**Triiodothyronine: Plant-based (vs Control)**

![][image173]
[image173]: /blog/plantbasedmeta/image173.png 

**Triiodothyronine: Plant-based (vs Baseline)**

![][image174]
[image174]: /blog/plantbasedmeta/image174.png 

# THYROXINE

**Thyroxine: Plant-based (vs Control)**

![][image175]
[image175]: /blog/plantbasedmeta/image175.png 

**Thyroxine: Plant-based (vs Baseline)**

![][image176]
[image176]: /blog/plantbasedmeta/image176.png 

# FREE TRIIODOTHYRONINE

**Free Triiodothyronine: Plant-based (vs Control)**

![][image177]
[image177]: /blog/plantbasedmeta/image177.png 

**Free Triiodothyronine: Plant-based (vs Baseline)**

![][image178]
[image-45]: /blog/plantbasedmeta/image-4-45.png

# THYROXINE

**Free Thyroxine: Plant-based (vs Control)**

![][image178]
[image178]: /blog/plantbasedmeta/image178.png 

**Free Thyroxine: Plant-based (vs Baseline)**

![][image179]
[image179]: /blog/plantbasedmeta/image179.png 

# THYROID STIMULATING HORMONE

**Thyroid Stimulating Hormone: Plant-based (vs Control)**

![][image180]
[image180]: /blog/plantbasedmeta/image180.png 

**Thyroid Stimulating Hormone: Plant-based (vs Baseline)**

![][image181]
[image181]: /blog/plantbasedmeta/image181.png 

# ENERGETICS

# ENERGY EXPENDITURE

**Energy Expenditure: Plant-based (vs Control)**

![][image182]
[image182]: /blog/plantbasedmeta/image182.png 

**Energy Expenditure: Plant-based (vs Baseline)**

![][image183]
[image183]: /blog/plantbasedmeta/image183.png 

**Energy Expenditure: Plant-based by Duration (vs Control)**

![][image184]
[image184]: /blog/plantbasedmeta/image184.png 

**Energy Expenditure: Plant-based by Duration (vs Baseline)**

![][image185]
[image185]: /blog/plantbasedmeta/image185.png 

**Energy Expenditure: Plant-based by Weight Loss (vs Control)**

![][image186]
[image186]: /blog/plantbasedmeta/image186.png 

**Energy Expenditure: Plant-based by Weight Loss (vs Baseline)**

![][image187]
[image187]: /blog/plantbasedmeta/image187.png 

Thank you for reading! If you like what you've read and want help me create more content like this, consider pledging your [Support](https://www.uprootnutrition.com/donate). Every little bit helps! I hope you found the content interesting!

# BIBLIOGRAPHY"""
    , articleReferences =
        [ { author = "Agren, J. J., et al."
          , title = "Divergent Changes in Serum Sterols during a Strict Uncooked Vegan Diet in Patients with Rheumatoid Arthritis"
          , journal = "The British Journal of Nutrition"
          , year = "2001"
          , link = "https://doi.org/10.1079/bjn2000234"
          }
        , { author = "Alleman, Rick J., et al."
          , title = "Both a Traditional and Modified Daniel Fast Improve the Cardio-Metabolic Profile in Men and Women"
          , journal = "Lipids in Health and Disease"
          , year = "2013"
          , link = "https://doi.org/10.1186/1476-511X-12-114"
          }
        , { author = "Barnard, N. D., et al."
          , title = "Effectiveness of a Low-Fat Vegetarian Diet in Altering Serum Lipids in Healthy Premenopausal Women"
          , journal = "The American Journal of Cardiology"
          , year = "2000"
          , link = "https://doi.org/10.1016/s0002-9149(99)00911-x"
          }
        , { author = "Barnard, Neal D., et al."
          , title = "The Effects of a Low-Fat, Plant-Based Dietary Intervention on Body Weight, Metabolism, and Insulin Sensitivity"
          , journal = "The American Journal of Medicine"
          , year = "2005"
          , link = "https://doi.org/10.1016/j.amjmed.2005.03.039"
          }
        , { author = "Barnard, Neal D., et al."
          , title = "A Low-Fat Vegan Diet Improves Glycemic Control and Cardiovascular Risk Factors in a Randomized Clinical Trial in Individuals with Type 2 Diabetes"
          , journal = "Diabetes Care"
          , year = "2006"
          , link = "https://doi.org/10.2337/dc06-0606"
          }
        , { author = "Barnard, Neal D., et al."
          , title = "A Low-Fat Vegan Diet and a Conventional Diabetes Diet in the Treatment of Type 2 Diabetes: A Randomized, Controlled, 74-Wk Clinical Trial"
          , journal = "The American Journal of Clinical Nutrition"
          , year = "2009"
          , link = "https://doi.org/10.3945/ajcn.2009.26736H"
          }
        , { author = "Barnard, Neal D., et al."
          , title = "Turning the Waiting Room into a Classroom: Weekly Classes Using a Vegan or a Portion-Controlled Eating Plan Improve Diabetes Control in a Randomized Translational Study"
          , journal = "Journal of the Academy of Nutrition and Dietetics"
          , year = "2018"
          , link = "https://doi.org/10.1016/j.jand.2017.11.017"
          }
        , { author = "Barnard, Neal D., et al."
          , title = "A Mediterranean Diet and Low-Fat Vegan Diet to Improve Body Weight and Cardiometabolic Risk Factors: A Randomized, Cross-over Trial"
          , journal = "Journal of the American Nutrition Association"
          , year = "2022"
          , link = "https://doi.org/10.1080/07315724.2020.1869625"
          }
        , { author = "Bloomer, Richard J., et al."
          , title = "Comparison of a Restricted and Unrestricted Vegan Diet Plan with a Restricted Omnivorous Diet Plan on Health-Specific Measures"
          , journal = "Healthcare (Basel, Switzerland)"
          , year = "2015"
          , link = "https://doi.org/10.3390/healthcare3030544"
          }
        , { author = "Bunner, Anne E., et al."
          , title = "Nutrition Intervention for Migraine: A Randomized Crossover Trial"
          , journal = "The Journal of Headache and Pain"
          , year = "2014"
          , link = "https://doi.org/10.1186/1129-2377-15-69"
          }
        , { author = "Crimarco, Anthony, et al."
          , title = "A Randomized Crossover Trial on the Effect of Plant-Based Compared with Animal-Based Meat on Trimethylamine-N-Oxide and Cardiovascular Disease Risk Factors in Generally Healthy Adults: Study With Appetizing Plantfood-Meat Eating Alternative Trial (SWAP-MEAT)"
          , journal = "The American Journal of Clinical Nutrition"
          , year = "2020"
          , link = "https://doi.org/10.1093/ajcn/nqaa203"
          }
        , { author = "David, Lawrence A., et al."
          , title = "Diet Rapidly and Reproducibly Alters the Human Gut Microbiome"
          , journal = "Nature"
          , year = "2014"
          , link = "https://doi.org/10.1038/nature12820"
          }
        , { author = "De Natale, Claudia, et al."
          , title = "Effects of a Plant-Based High-Carbohydrate/High-Fiber Diet versus High-Monounsaturated Fat/Low-Carbohydrate Diet on Postprandial Lipids in Type 2 Diabetic Patients"
          , journal = "Diabetes Care"
          , year = "2009"
          , link = "https://doi.org/10.2337/dc09-0266"
          }
        , { author = "Crosby, Lelia, et al."
          , title = "Changes in Food and Nutrient Intake and Diet Quality on a Low-Fat Vegan Diet Are Associated with Changes in Body Weight, Body Composition, and Insulin Sensitivity in Overweight Adults: A Randomized Clinical Trial"
          , journal = "Journal of the Academy of Nutrition and Dietetics"
          , year = "2022"
          , link = "https://doi.org/10.1016/j.jand.2022.04.008"
          }
        , { author = "Draper, Colleen Fogarty, et al."
          , title = "Vegan and Animal Meal Composition and Timing Influence Glucose and Lipid Related Postprandial Metabolic Profiles"
          , journal = "Molecular Nutrition & Food Research"
          , year = "2019"
          , link = "https://doi.org/10.1002/mnfr.201800568"
          }
        , { author = "Elkan, Ann-Charlotte, et al."
          , title = "Gluten-Free Vegan Diet Induces Decreased LDL and Oxidized LDL Levels and Raised Atheroprotective Natural Antibodies against Phosphorylcholine in Patients with Rheumatoid Arthritis: A Randomized Study"
          , journal = "Arthritis Research & Therapy"
          , year = "2008"
          , link = "https://doi.org/10.1186/ar2388"
          }
        , { author = "Ferdowsian, Hope R., et al."
          , title = "A Multicomponent Intervention Reduces Body Weight and Cardiovascular Risk at a GEICO Corporate Site"
          , journal = "American Journal of Health Promotion: AJHP"
          , year = "2010"
          , link = "https://doi.org/10.4278/ajhp.081027-QUAN-255"
          }
        , { author = "Gardner, Christopher D., et al."
          , title = "The Effect of a Plant-Based Diet on Plasma Lipids in Hypercholesterolemic Adults: A Randomized Trial"
          , journal = "Annals of Internal Medicine"
          , year = "2005"
          , link = "https://doi.org/10.7326/0003-4819-142-9-200505030-00007"
          }
        , { author = "Hall, Kevin D., et al."
          , title = "Effect of a Plant-Based, Low-Fat Diet versus an Animal-Based, Ketogenic Diet on Ad Libitum Energy Intake"
          , journal = "Nature Medicine"
          , year = "2021"
          , link = "https://doi.org/10.1038/s41591-020-01209-1"
          }
        , { author = "Jenkins, David J. A., et al."
          , title = "The Effect of a Plant-Based Low-Carbohydrate (‘Eco-Atkins’) Diet on Body Weight and Blood Lipid Concentrations in Hyperlipidemic Subjects"
          , journal = "Archives of Internal Medicine"
          , year = "2009"
          , link = "https://doi.org/10.1001/archinternmed.2009.115"
          }
        , { author = "Jenkins, David J. A., et al."
          , title = "Effect of a Dietary Portfolio of Cholesterol-Lowering Foods given at 2 Levels of Intensity of Dietary Advice on Serum Lipids in Hyperlipidemia: A Randomized Controlled Trial."
          , journal = "JAMA"
          , year = "2011"
          , link = "https://doi.org/10.1001/jama.2011.1202"
          }
        , { author = "Jenkins, David J. A., et al."
          , title = "Effect of a 6-Month Vegan Low-Carbohydrate ('Eco-Atkins’) Diet on Cardiovascular Risk Factors and Body Weight in Hyperlipidaemic Adults: A Randomised Controlled Trial."
          , journal = "BMJ Open"
          , year = "2014"
          , link = "https://doi.org/10.1136/bmjopen-2013-003505"
          }
        , { author = "Kaartinen, K., et al."
          , title = "Vegan Diet Alleviates Fibromyalgia Symptoms."
          , journal = "Scandinavian Journal of Rheumatology"
          , year = "2000"
          , link = "https://doi.org/10.1080/030097400447697"
          }
        , { author = "Kahleova, Hana, et al."
          , title = "A Plant-Based High-Carbohydrate, Low-Fat Diet in Overweight Individuals in a 16-Week Randomized Clinical Trial: The Role of Carbohydrates."
          , journal = "Nutrients"
          , year = "2018"
          , link = "https://doi.org/10.3390/nu10091302"
          }
        , { author = "Kahleova, Hana, et al."
          , title = "A Plant-Based Meal Stimulates Incretin and Insulin Secretion More Than an Energy- and Macronutrient-Matched Standard Meal in Type 2 Diabetes: A Randomized Crossover Study."
          , journal = "Nutrients"
          , year = "2019"
          , link = "https://doi.org/10.3390/nu11030486"
          }
        , { author = "Kahleova, Hana, et al."
          , title = "Effect of a Low-Fat Vegan Diet on Body Weight, Insulin Sensitivity, Postprandial Metabolism, and Intramyocellular and Hepatocellular Lipid Levels in Overweight Adults: A Randomized Clinical Trial."
          , journal = "JAMA Network Open"
          , year = "2020"
          , link = "https://doi.org/10.1001/jamanetworkopen.2020.25454"
          }
        , { author = "Kahleova, Hana, et al."
          , title = "Fat Quantity and Quality, as Part of a Low-Fat, Vegan Diet, Are Associated with Changes in Body Composition, Insulin Resistance, and Insulin Secretion. A 16-Week Randomized Controlled Trial."
          , journal = "Nutrients"
          , year = "2019"
          , link = "https://doi.org/10.3390/nu11030615"
          }
        , { author = "Kjeldsen-Kragh, J., et al."
          , title = "Vegetarian Diet for Patients with Rheumatoid Arthritis: Can the Clinical Effects Be Explained by the Psychological Characteristics of the Patients?"
          , journal = "British Journal of Rheumatology"
          , year = "1994"
          , link = "https://doi.org/10.1093/rheumatology/33.6.569"
          }
        , { author = "Klementova, Marta, et al."
          , title = "A Plant-Based Meal Increases Gastrointestinal Hormones and Satiety More Than an Energy- and Macronutrient-Matched Processed-Meat Meal in T2D, Obese, and Healthy Men: A Three-Group Randomized Crossover Study."
          , journal = "Nutrients"
          , year = "2019"
          , link = "https://doi.org/10.3390/nu11010157"
          }
        , { author = "Koebnick, C., et al."
          , title = "Double-Blind, Randomized Feedback Control Fails to Improve the Hypocholesterolemic Effect of a Plant-Based Low-Fat Diet in Patients with Moderately Elevated Total Cholesterol Levels."
          , journal = "European Journal of Clinical Nutrition"
          , year = "2004"
          , link = "https://doi.org/10.1038/sj.ejcn.1601984"
          }
        , { author = "Lederer, Ann-Kathrin, et al."
          , title = "Vitamin B12 Status Upon Short-Term Intervention with a Vegan Diet-A Randomized Controlled Trial in Healthy Participants."
          , journal = "Nutrients"
          , year = "2019"
          , link = "https://doi.org/10.3390/nu11112815"
          }
        , { author = "Lee, Yu-Mi, et al."
          , title = "Effect of a Brown Rice Based Vegan Diet and Conventional Diabetic Diet on Glycemic Control of Patients with Type 2 Diabetes: A 12-Week Randomized Clinical Trial."
          , journal = "PloS One"
          , year = "2016"
          , link = "https://doi.org/10.1371/journal.pone.0155918"
          }
        , { author = "Ling, W. H., and O. Hänninen."
          , title = "Shifting from a Conventional Diet to an Uncooked Vegan Diet Reversibly Alters Fecal Hydrolytic Activities in Humans."
          , journal = "The Journal of Nutrition"
          , year = "1992"
          , link = "https://doi.org/10.1093/jn/122.4.924"
          }
        , { author = "Macknin, Michael, et al."
          , title = "Plant-Based, No-Added-Fat or American Heart Association Diets: Impact on Cardiovascular Risk in Obese Children with Hypercholesterolemia and Their Parents."
          , journal = "The Journal of Pediatrics"
          , year = "2015"
          , link = "https://doi.org/10.1016/j.jpeds.2014.12.058"
          }
        , { author = "Mishra, S., et al."
          , title = "A Multicenter Randomized Controlled Trial of a Plant-Based Nutrition Program to Reduce Body Weight and Cardiovascular Risk in the Corporate Setting: The GEICO Study."
          , journal = "European Journal of Clinical Nutrition"
          , year = "2013"
          , link = "https://doi.org/10.1038/ejcn.2013.92"
          }
        , { author = "Neacsu, Madalina, et al."
          , title = "Appetite Control and Biomarkers of Satiety with Vegetarian (Soy) and Meat-Based High-Protein Diets for Weight Loss in Obese Men: A Randomized Crossover Trial."
          , journal = "The American Journal of Clinical Nutrition"
          , year = "2014"
          , link = "https://doi.org/10.3945/ajcn.113.077503"
          }
        , { author = "Nicholson, A. S., et al."
          , title = "Toward Improved Management of NIDDM: A Randomized, Controlled, Pilot Intervention Using a Lowfat, Vegetarian Diet."
          , journal = "Preventive Medicine"
          , year = "1999"
          , link = "https://doi.org/10.1006/pmed.1999.0529"
          }
        , { author = "Ornish, D., et al."
          , title = "Can Lifestyle Changes Reverse Coronary Heart Disease? The Lifestyle Heart Trial."
          , journal = "Lancet (London, England)"
          , year = "1990"
          , link = "https://doi.org/10.1016/0140-6736(90)91656-u"
          }
        , { author = "Ornish, D., et al."
          , title = "Intensive Lifestyle Changes for Reversal of Coronary Heart Disease."
          , journal = "JAMA"
          , year = "1998"
          , link = "https://doi.org/10.1001/jama.280.23.2001"
          }
        , { author = "Päivärinta, Essi, et al."
          , title = "Replacing Animal-Based Proteins with Plant-Based Proteins Changes the Composition of a Whole Nordic Diet-A Randomised Clinical Trial in Healthy Finnish Adults."
          , journal = "Nutrients"
          , year = "2020"
          , link = "https://doi.org/10.3390/nu12040943"
          }
        , { author = "Peltonen, R., et al."
          , title = "Faecal Microbial Flora and Disease Activity in Rheumatoid Arthritis during a Vegan Diet."
          , journal = "British Journal of Rheumatology"
          , year = "1997"
          , link = "https://doi.org/10.1093/rheumatology/36.1.64"
          }
        , { author = "Ramal, Edelweiss, et al."
          , title = "Impact of a Plant-Based Diet and Support on Mitigating Type 2 Diabetes Mellitus in Latinos Living in Medically Underserved Areas."
          , journal = "American Journal of Health Promotion: AJHP"
          , year = "2018"
          , link = "https://doi.org/10.1177/0890117117706793"
          }
        , { author = "Shah, Binita, et al."
          , title = "Anti-Inflammatory Effects of a Vegan Diet Versus the American Heart Association-Recommended Diet in Coronary Artery Disease Trial."
          , journal = "Journal of the American Heart Association"
          , year = "2018"
          , link = "https://doi.org/10.1161/JAHA.118.011367"
          }
        , { author = "Sofi, Francesco, et al."
          , title = "Low-Calorie Vegetarian Versus Mediterranean Diets for Reducing Body Weight and Improving Cardiovascular Risk Profile: CARDIVEG Study (Cardiovascular Prevention With Vegetarian Diet)."
          , journal = "Circulation"
          , year = "2018"
          , link = "https://doi.org/10.1161/CIRCULATIONAHA.117.030088"
          }
        , { author = "Sutliffe, Jay T., et al."
          , title = "C-Reactive Protein Response to a Vegan Lifestyle Intervention."
          , journal = "Complementary Therapies in Medicine"
          , year = "2015"
          , link = "https://doi.org/10.1016/j.ctim.2014.11.001"
          }
        , { author = "Turner-McGrievy, Gabrielle M., et al."
          , title = "A Two-Year Randomized Weight Loss Trial Comparing a Vegan Diet to a More Moderate Low-Fat Diet."
          , journal = "Obesity (Silver Spring, Md.)"
          , year = "2007"
          , link = "https://doi.org/10.1038/oby.2007.270"
          }
        , { author = "Turner-McGrievy, Gabrielle M., et al."
          , title = "Low Glycemic Index Vegan or Low-Calorie Weight Loss Diets for Women with Polycystic Ovary Syndrome: A Randomized Controlled Feasibility Study."
          , journal = "Nutrition Research (New York, N.Y.)"
          , year = "2014"
          , link = "https://doi.org/10.1016/j.nutres.2014.04.011"
          }
        , { author = "Turner-McGrievy, Gabrielle M., et al."
          , title = "Comparative Effectiveness of Plant-Based Diets for Weight Loss: A Randomized Controlled Trial of Five Different Diets."
          , journal = "Nutrition (Burbank, Los Angeles County, Calif.)"
          , year = "2015"
          , link = "https://doi.org/10.1016/j.nut.2014.09.002"
          }
        , { author = "Turner-McGrievy, Gabrielle M., et al."
          , title = "Randomization to Plant-Based Dietary Approaches Leads to Larger Short-Term Improvements in Dietary Inflammatory Index Scores and Macronutrient Intake Compared with Diets That Contain Meat."
          , journal = "Nutrition Research (New York, N.Y.)"
          , year = "2015"
          , link = "https://doi.org/10.1016/j.nutres.2014.11.007"
          }
        , { author = "Wright, N., et al."
          , title = "The BROAD Study: A Randomised Controlled Trial Using a Whole Food Plant-Based Diet in the Community for Obesity, Ischaemic Heart Disease or Diabetes."
          , journal = "Nutrition & Diabetes"
          , year = "2017"
          , link = "https://doi.org/10.1038/nutd.2017.3"
          }
        , { author = "Yadav, Vijayshree, et al."
          , title = "Low-Fat, Plant-Based Diet in Multiple Sclerosis: A Randomized Controlled Trial."
          , journal = "Multiple Sclerosis and Related Disorders"
          , year = "2016"
          , link = "https://doi.org/10.1016/j.msard.2016.07.001"
          }
        ]
    }
