module Config.Pages.Debate.Arguments.Records.DietaryCholesterol exposing (argumentDietaryCholesterol)

import Config.Data.Hashtags.Types exposing (Hashtags(..))
import Config.Helpers.Converters exposing (toTitleCase)
import Config.Pages.Debate.Arguments.Types exposing (Argument)


argumentDietaryCholesterol : Argument
argumentDietaryCholesterol =
    { argumentTitle = toTitleCase "Argument for Atherogenic Dietary Cholesterol"
    , propositionTitle = "Consuming high amounts of dietary cholesterol increases heart disease risk."
    , propositionReductio = ""
    , propositionSummary = "LDL causally associates with heart disease in a linear and proportional manner, and in all cases exposures that durably increase LDL over time produce likewise increases in heart disease risk. Dietary cholesterol is one such exposure."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~5Qx)),(Pd)|=(Qd)"
    , argumentCertainty = 9
    , argumentImage = "dietarycholesterol"
    , argumentHashtags = []
    , isNewTabLink = False
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "consuming high amounts of (x) increases LDL"
          }
        , { definiendum = "Q(x)"
          , definiens = "(x) increases heart disease risk"
          }
        , { definiendum = "x"
          , definiens = "a substance"
          }
        , { definiendum = "d"
          , definiens = "dietary cholesterol"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if consuming high amounts of a substance increases LDL, then consuming high amounts of a substance increases heart disease risk."
                  , notation = "∀x(Px→Qx)"
                  }
                , { premise = "Consuming high amounts of dietary cholesterol increases LDL."
                  , notation = "Pd"
                  }
                ]
          , conclusion = "Therefore, consuming high amounts of dietary cholesterol increases heart disease risk."
          , conclusionNotation = "Qd"
          }
        ]
    }
