module Config.Pages.Debate.Arguments.Records.FructoseNAFLD exposing (argumentFructoseNAFLD)

import Config.Data.Hashtags.Types exposing (Hashtags(..))
import Config.Helpers.Converters exposing (toTitleCase)
import Config.Pages.Debate.Arguments.Types exposing (Argument)


argumentFructoseNAFLD : Argument
argumentFructoseNAFLD =
    { argumentTitle = toTitleCase "Argument Against Lipogenic Fructose"
    , propositionTitle = "Fructose doesn't seem to uniquely cause fatty liver disease."
    , propositionReductio = ""
    , propositionSummary = "Experimental investigations into fructose overfeeding have consistently failed to produce a fatty liver phenotype in humans. This suggests that fructose, contrary to popular belief in some domains, does not uniquely cause fatty liver disease."
    , proofLink = "https://www.umsu.de/trees/#(P~5~3Q),(P)|=(~3Q)"
    , argumentCertainty = 8
    , argumentImage = "fructosenafld"
    , argumentHashtags = []
    , isNewTabLink = False
    , definitionTable =
        [ { definiendum = "P"
          , definiens = "experimental investigations into fructose overfeeding consistently fail to recreate a fatty liver phenotype in humans"
          }
        , { definiendum = "Q"
          , definiens = "fructose seems to uniquely cause fatty liver disease"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "If experimental investigations into fructose overfeeding consistently fail to recreate a fatty liver phenotype in humans, then fructose does not seem to uniquely cause fatty liver disease."
                  , notation = "P→¬Q"
                  }
                , { premise = "Experimental investigations into fructose overfeeding consistently fail to recreate a fatty liver phenotype in humans."
                  , notation = "P"
                  }
                ]
          , conclusion = "Therefore, fructose does not seem to uniquely cause fatty liver disease."
          , conclusionNotation = "¬Q"
          }
        ]
    }
