module Config.Pages.Debate.Arguments.Records.HealthyFibre exposing (argumentHealthyFibre)

import Config.Data.Hashtags.Types exposing (Hashtags(..))
import Config.Helpers.Converters exposing (toTitleCase)
import Config.Pages.Debate.Arguments.Types exposing (Argument)


argumentHealthyFibre : Argument
argumentHealthyFibre =
    { argumentTitle = toTitleCase "Argument for  Healthy Fibre"
    , propositionTitle = "Fibre, whether whole or refined, is  healthy."
    , propositionReductio = ""
    , propositionSummary = "Even when you account for factors that could plausibly influence the results, both refined and whole fibre have been shown to consistently reduce the risk of morbidity and mortality, strongly suggesting that they directly contribute to better health outcomes, particularly with respect to cardiovascular disease."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~4Qx)),(Qb)|=(Pb)"
    , argumentCertainty = 9
    , argumentImage = "fibre"
    , argumentHashtags = []
    , isNewTabLink = False
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) has a strong tendency to associate with a reduced risk of morbidity and/or mortality after adjusting and/or controlling for relevant variables."
          }
        , { definiendum = "Q(x)"
          , definiens = "there is a dearth of epistemically countervailing data on (x)."
          }
        , { definiendum = "R(x)"
          , definiens = "it is more reasonable to believe that (x) is  healthy than it is to believe the opposite."
          }
        , { definiendum = "x"
          , definiens = "a food"
          }
        , { definiendum = "f"
          , definiens = "fibre"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if a food has a strong tendency to associate with a reduced risk of morbidity and/or mortality after adjusting and/or controling for relevant variables and there is a dearth of epistemically countervailing data on that food, then it is more reasonable to believe that the food is healthy than it is to believe the opposite."
                  , notation = "∀x((Px∧Qx)→Rx)"
                  }
                , { premise = "Fibre has a strong tendency to associate with a reduced risk of morbidity and mortality after adjustment and/or controlling for relevant variables."
                  , notation = "Pf"
                  }
                , { premise = "There is a dearth of epistemically countervailing data on fibre."
                  , notation = "Qf"
                  }
                ]
          , conclusion = "Therefore, it is more reasonable to believe that fibre is healthy than it is to believe the opposite."
          , conclusionNotation = "Rf"
          }
        ]
    }
