module Config.Pages.Debate.Arguments.Records.HealthyPlantFoods exposing (argumentHealthyPlantFoods)

import Config.Data.Hashtags.Types exposing (Hashtags(..))
import Config.Helpers.Converters exposing (toTitleCase)
import Config.Pages.Debate.Arguments.Types exposing (Argument)


argumentHealthyPlantFoods : Argument
argumentHealthyPlantFoods =
    { argumentTitle = toTitleCase "Argument for  Healthy Plant Foods"
    , propositionTitle = "Whole plant foods are  healthy."
    , propositionReductio = ""
    , propositionSummary = "Since whole plant foods consistently consistently associate with reduced risk of illness and death, it is reasonable to conclude that whole plant foods are  healthy."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~4Qx)),(Qf)|=(Pf)"
    , argumentCertainty = 9
    , argumentImage = "plantfoods"
    , argumentHashtags = []
    , isNewTabLink = False
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) has a strong tendency to associate with a reduced risk of morbidity and/or mortality after adjusting and/or controlling for relevant variables."
          }
        , { definiendum = "Q(x)"
          , definiens = "there is a dearth of epistemically countervailing data on (x)."
          }
        , { definiendum = "R(x)"
          , definiens = "it is more reasonable to believe that (x) is  healthy than it is to believe the opposite."
          }
        , { definiendum = "x"
          , definiens = "a food"
          }
        , { definiendum = "w"
          , definiens = "whole plant foods"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if a food has a strong tendency to associate with a reduced risk of morbidity and/or mortality after adjusting and/or controling for relevant variables and there is a dearth of epistemically countervailing data on that food, then it is more reasonable to believe that the food is healthy than it is to believe the opposite."
                  , notation = "∀x((Px∧Qx)→Rx)"
                  }
                , { premise = "Whole plant foods have a strong tendency to associate with a reduced risk of morbidity and mortality after adjustment and/or controlling for relevant variables."
                  , notation = "Pw"
                  }
                , { premise = "There is a dearth of epistemically countervailing data on whole plant foods."
                  , notation = "Qw"
                  }
                ]
          , conclusion = "Therefore, it is more reasonable to believe that whole plant foods are healthy than it is to believe the opposite."
          , conclusionNotation = "Rw"
          }
        ]
    }
