module Config.Pages.Debate.Arguments.Records.HealthySoy exposing (argumentHealthySoy)

import Config.Data.Hashtags.Types exposing (Hashtags(..))
import Config.Helpers.Converters exposing (toTitleCase)
import Config.Pages.Debate.Arguments.Types exposing (Argument)


argumentHealthySoy : Argument
argumentHealthySoy =
    { argumentTitle = toTitleCase "Argument for Healthy Soy Products"
    , propositionTitle = "Soy products are  healthy."
    , propositionReductio = ""
    , propositionSummary = "Even when you account for factors that could plausibly influence the results, non-hydrogenated soy products have been shown to consistently reduce the risk of morbidity and mortality, strongly suggesting that they directly contribute to better health outcomes, particularly with respect to cardiovascular disease."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~4Qx)),(Qs)|=(Ps)"
    , argumentCertainty = 7
    , argumentImage = "soyproducts"
    , argumentHashtags = []
    , isNewTabLink = False
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) has a strong tendency to associate with a reduced risk of morbidity and/or mortality after adjusting and/or controlling for relevant variables."
          }
        , { definiendum = "Q(x)"
          , definiens = "there is a dearth of epistemically countervailing data on (x)."
          }
        , { definiendum = "R(x)"
          , definiens = "it is more reasonable to believe that (x) is  healthy than it is to believe the opposite."
          }
        , { definiendum = "x"
          , definiens = "a food"
          }
        , { definiendum = "s"
          , definiens = "soy products"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if a food has a strong tendency to associate with a reduced risk of morbidity and/or mortality after adjusting and/or controling for relevant variables and there is a dearth of epistemically countervailing data on that food, then it is more reasonable to believe that the food is healthy than it is to believe the opposite."
                  , notation = "∀x((Px∧Qx)→Rx)"
                  }
                , { premise = "Soy products have a strong tendency to associate with a reduced risk of morbidity and mortality after adjustment and/or controlling for relevant variables."
                  , notation = "Ps"
                  }
                , { premise = "There is a dearth of epistemically countervailing data on soy products."
                  , notation = "Qs"
                  }
                ]
          , conclusion = "Therefore, it is more reasonable to believe that soy products are healthy than it is to believe the opposite."
          , conclusionNotation = "Rs"
          }
        ]
    }
