module Config.Pages.Debate.Arguments.Records.Omega3Omega6Ratio exposing (argumentOmega3Omega6Ratio)

import Config.Data.Hashtags.Types exposing (Hashtags(..))
import Config.Helpers.Converters exposing (toTitleCase)
import Config.Pages.Debate.Arguments.Types exposing (Argument)


argumentOmega3Omega6Ratio : Argument
argumentOmega3Omega6Ratio =
    { argumentTitle = toTitleCase "Argument Against the Omega-6/Omega-3 Ratio"
    , propositionTitle = "The omega-6/omega-3 ratio is unlikely to matter for health."
    , propositionReductio = ""
    , propositionSummary = "More often than not, the associated risks of a high omega-6/omega-3 ratio are better explained by omega-3 alone. In multivariable analyses, the ratio looks like it matters, but in univariable anaylses, low omega-3 is almost always driving the risk via lowering the denominator."
    , proofLink = "https://www.umsu.de/trees/#(P~5Q),(~3Q)|=(~3P)"
    , argumentCertainty = 7
    , argumentImage = "omega6omega3ratio"
    , argumentHashtags = []
    , isNewTabLink = False
    , definitionTable =
        [ { definiendum = "P"
          , definiens = "increases or decreases in disease risk associated with a high or low omega-6/omega-3 ratio are better explained by changes in omega-3 alone"
          }
        , { definiendum = "Q"
          , definiens = "the omega-6/omega-3 ratio is likely to matter for health"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "If increases or decreases in disease risk associated with a high or low omega-6/omega-3 ratio are better explained by changes in omega-3 alone, then the omega-6/omega-3 ratio is not likely to matter for health."
                  , notation = "P→¬Q"
                  }
                , { premise = "Increases or decreases in disease risk associated with a high or low omega-6/omega-3 ratio are better explained by changes in omega-3 alone."
                  , notation = "P"
                  }
                ]
          , conclusion = "Therefore, the omega-6/omega-3 ratio is not likely to matter for health."
          , conclusionNotation = "¬Q"
          }
        ]
    }
