module Config.Pages.Debate.Arguments.Records.UnhealthySaturatedFat exposing (argumentUnhealthySaturatedFat)

import Config.Data.Hashtags.Types exposing (Hashtags(..))
import Config.Helpers.Converters exposing (toTitleCase)
import Config.Pages.Debate.Arguments.Types exposing (Argument)


argumentUnhealthySaturatedFat : Argument
argumentUnhealthySaturatedFat =
    { argumentTitle = toTitleCase "Argument Against Saturated Animal Fat"
    , propositionTitle = "Most sources of saturated fat are  unhealthy."
    , propositionReductio = ""
    , propositionSummary = "Even when you account for factors that could plausibly influence the results, most animal-derived saturated fats have been shown to consistently increase the risk of morbidity and mortality, strongly suggesting that they directly contribute to worse health outcomes, particularly with respect to heart disease and non-alcoholic fatty liver disease."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~4Qx)),(Qf)|=(Pf)"
    , argumentCertainty = 9
    , argumentImage = "saturatedfat"
    , argumentHashtags = []
    , isNewTabLink = False
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) has a strong tendency to associate with an increased risk of morbidity and/or mortality after adjusting and/or controlling for relevant variables."
          }
        , { definiendum = "Q(x)"
          , definiens = "there is a dearth of epistemically countervailing data on (x)."
          }
        , { definiendum = "R(x)"
          , definiens = "it is more reasonable to believe that (x) is  unhealthy than it is to believe the opposite."
          }
        , { definiendum = "x"
          , definiens = "a food"
          }
        , { definiendum = "s"
          , definiens = "saturated animal fat"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if a food has a strong tendency to associate with an increased risk of morbidity and/or mortality after adjusting and/or controling for relevant variables and there is a dearth of epistemically countervailing data on that food, then it is more reasonable to believe that the food is healthy than it is to believe the opposite."
                  , notation = "∀x((Px∧Qx)→Rx)"
                  }
                , { premise = "Saturated animal fat has a strong tendency to associate with an increased risk of morbidity and mortality after adjustment and/or controlling for relevant variables."
                  , notation = "Ps"
                  }
                , { premise = "There is a dearth of epistemically countervailing data on saturated animal fat."
                  , notation = "Qs"
                  }
                ]
          , conclusion = "Therefore, it is more reasonable to believe that saturated animal fat is unhealthy than it is to believe the opposite."
          , conclusionNotation = "Rs"
          }
        ]
    }
