module Config.Pages.Debate.Gibberish.Records.PhilOfMind exposing (philOfMindGibberish)

import Config.Data.Hashtags.Types exposing (Hashtags(..))
import Config.Helpers.Converters exposing (formatName)
import Config.Pages.Debate.Gibberish.Types
    exposing
        ( Explanation(..)
        , Gibberish
        , Terms
        )


philOfMindGibberish : Gibberish
philOfMindGibberish =
    let
        name =
            "Philosophy of Mind"
    in
    { gibberishTitle = name
    , gibberishImage = formatName name
    , gibberishLink = "https://en.wikipedia.org/wiki/Philosophy_of_mind"
    , gibberishDescription = "The philosophy of mind is a branch of philosophy that explores the nature of the mind, consciousness, and mental phenomena, particularly their relationship to the body and the physical world. It addresses fundamental questions about how mental states such as thoughts, feelings, and perceptions relate to brain processes and the external environment. Key topics include consciousness, intentionality, and the mind-body problem, which examines how mental and physical states interact."
    , isNewTabLink = True
    , gibberishTerms =
        [ { term = "Epiphenomenalism"
          , strength = 5
          , explanation = NoClue
          }
        , { term = "Mind-Heart Connection"
          , strength = 5
          , explanation = NoClue
          }
        , { term = "Parallelism"
          , strength = 5
          , explanation = NoClue
          }
        , { term = "Pre-Established Harmony"
          , strength = 5
          , explanation = NoClue
          }
        , { term = "Private Language"
          , strength = 5
          , explanation = SpecificExplanation "This seems to be taken to be describing terms that, ostensibly, refer only to internal mind-states and for which there supposedly \"can't\" be some sort of external reference upon which to base mutual understanding between agents. Supposedly, this renders such terms unintelligible to everyone else. Cool story. What in the world is meant by \"can't\", though?"
          }
        ]
    }
