module Config.Pages.Debate.Arguments.Records.VeganSocietyReductio exposing (argumentVeganSocietyReductio)

import Config.Data.Hashtags.Types exposing (Hashtags(..))
import Config.Helpers.Converters exposing (toTitleCase)
import Config.Pages.Debate.Arguments.Types exposing (Argument)


argumentVeganSocietyReductio : Argument
argumentVeganSocietyReductio =
    { argumentTitle = toTitleCase "Vegan Society Definition Reductio"
    , propositionTitle = "It is vegan to eat Groot."
    , propositionReductio = "Those who hold to the Vegan Society's definition of veganism index the object of moral value to belonging to the animal kingdom."
    , propositionSummary = "If one holds to the position that exploiting a being is wrong so long as that being is an animal, then it is straightforwardly entailed that exploiting creatures like Groot would be an action compatible with veganism."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~4~3Qx)),(~6x~6y(~3Rx~5~3Q(e(y)))),(~3Rg)%7C=(P(e(g)))"
    , argumentCertainty = 10
    , argumentImage = "vegansociety"
    , argumentHashtags = []
    , isNewTabLink = False
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "it is vegan to do (x)"
          }
        , { definiendum = "Q(x,y)"
          , definiens = "(x) exploits (y)"
          }
        , { definiendum = "R(x)"
          , definiens = "(x) is an animal"
          }
        , { definiendum = "x"
          , definiens = "a being"
          }
        , { definiendum = "y"
          , definiens = "an animal"
          }
        , { definiendum = "e"
          , definiens = "eat"
          }
        , { definiendum = "g"
          , definiens = "Groot"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, it is vegan to do something if, and only if, that thing does not exploit animals."
                  , notation = "∀x(Px↔¬Qx)"
                  }
                , { premise = "If some beings are not animals, then eating those beings does not exploit animals."
                  , notation = "∀x∀y(¬Rx→¬Q(e(y)))"
                  }
                , { premise = "Groot is not an animal."
                  , notation = "¬Rg"
                  }
                ]
          , conclusion = "Therefore, it is vegan to eat Groot."
          , conclusionNotation = "P(e(g))"
          }
        ]
    }
